OrStopped

Enum OrStopped 

pub enum OrStopped<E = Error> {
    Internal(E),
    Stopped,
}
Represents an error in a stoppable task: either an internal / fatal error, or a task getting stopped after receiving a stop request.

The Error trait is intentionally not implemented for this enum to force users to treat the Stopped variant with care. Depending on the application, it may not be an error. Use the try_stoppable! macro to handle this variant by early-returning Ok(()).

Variants



Internal(E)

Internal error.



Stopped

Graceful stop after receiving the corresponding request.

Implementations

Source

impl<E> OrStopped<E>

pub fn internal(err: impl Into<E>) -> Self

Maps an error to the Internal variant.