pub enum OrStopped<E = Error> {
Internal(E),
Stopped,
}Expand description
Represents an error in a stoppable task: either an internal / fatal error, or a task getting stopped after receiving a stop request.
The Error trait is intentionally not implemented for this enum to force users
to treat the Stopped variant with care. Depending on the application, it may not be an error.
Use the try_stoppable! macro to handle this variant by early-returning Ok(()).
Variants
Implementations